@@ -68,7 +68,7 @@ class Candidate:
 
 def get_project_from_pypi(project, extras):
     """Return candidates created from the project name and extras."""
-    url = "https://pypi.org/simple/{}".format(project)
+    url = f"https://pypi.org/simple/{project}"
     data = requests.get(url).content
     doc = html5lib.parse(data, namespaceHTMLElements=False)
     for i in doc.findall(".//a"):
@@ -120,7 +120,7 @@ class PyPIProvider(ExtrasProvider):
         return tuple(sorted(requirement_or_candidate.extras))
 
     def get_base_requirement(self, candidate):
-        return Requirement("{}=={}".format(candidate.name, candidate.version))
+        return Requirement(f"{candidate.name}=={candidate.version}")
 
     def get_preference(self, identifier, resolutions, candidates, information):
         return sum(1 for _ in candidates[identifier])
