@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import pytest
 
 from resolvelib import BaseReporter
@@ -8,13 +6,16 @@ from resolvelib import BaseReporter
 class TestReporter(BaseReporter):
     def __init__(self):
         self._indent = 0
+        self.visited = []
 
     def rejecting_candidate(self, criterion, candidate):
         self._indent -= 1
+        self.visited.append(candidate)
         print(" " * self._indent, "Reject ", candidate, sep="")
 
     def pinning(self, candidate):
         print(" " * self._indent, "Pin  ", candidate, sep="")
+        self.visited.append(candidate)
         self._indent += 1
 
 
